@@ -1,9 +1,10 @@
-from pandas_orm.sqlalchemy.model_dataframe_manager import ModelDataFrameManager
+from pandas_orm.sqlalchemy.crud.save import ModelDataFrameManager
 from pandas_orm.sqlalchemy.query import to_dataframe
-from pandas_orm.sqlalchemy.dataframe import DataFrame
+from pandas_orm.sqlalchemy.dataframe import DataFrame, initialized_dataframe
+from pandas_orm.sqlalchemy.session.sqlalchemy_db import DatabaseSession
 
 
-class ModelManager(ModelDataFrameManager):
+class ModelManager(DatabaseSession):
 
     def __init__(self, model, *args, **kwargs):
         super(__class__, self).__init__(*args, **kwargs)
@@ -14,6 +15,15 @@ class ModelManager(ModelDataFrameManager):
         with self.session() as session:
             return session.query(self.model)
 
+    def delete(self, **kwargs):
+        with self.session() as session:
+            prepared_statement = session.query(self.model)
+            for key, value in kwargs.items():
+                prepared_statement = prepared_statement.filter(
+                    getattr(self.model, key) == value
+                )
+            return prepared_statement.delete()
+
     @to_dataframe
     def get(self, **kwargs):
         with self.session() as session:
@@ -24,14 +34,17 @@ class ModelManager(ModelDataFrameManager):
                 )
             return prepared_statement
 
-    def bulk_save(self, records, unique_fields=None, update_fields=None, returning_id=False)->DataFrame:
-        return self._bulk_save(
+    def bulk_save(self, records, unique_fields=None, update_fields=None, returning_id=False, model=None) -> DataFrame:
+        model = model if model else self.model
+        new_records = ModelDataFrameManager.bulk_save(
             records=records,
-            model=self.model,
+            model=model,
             unique_fields=unique_fields,
             update_fields=update_fields,
-            returning_id=returning_id
+            returning_id=returning_id,
+            engine_context_func=self.engine
         )
+        return initialized_dataframe(new_records, self)
 
 
 
